Index: webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
diff --git a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
index c682c63210f0d7de3f7555de15bed2f699e7ca5e..147ff1b36b66d30a55ea39a1fbcc8552e65b3f49 100644 |
--- a/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
+++ b/webrtc/logging/rtc_event_log/rtc_event_log_parser.h |
@@ -114,10 +114,9 @@ class ParsedRtcEventLog { |
uint8_t* packet, |
size_t* length) const; |
// Reads a config event to a (non-NULL) VideoReceiveStream::Config struct. |
// Only the fields that are stored in the protobuf will be written. |
- void GetVideoReceiveConfig(size_t index, |
- VideoReceiveStream::Config* config) const; |
+ void GetVideoReceiveConfig(size_t index, rtclog::StreamConfig* config) const; |
// Reads a config event to a (non-NULL) VideoSendStream::Config struct. |
// Only the fields that are stored in the protobuf will be written. |
@@ -114,10 +114,9 @@ class ParsedRtcEventLog { |
uint8_t* packet, |
size_t* length) const; |
- // Reads a config event to a (non-NULL) VideoReceiveStream::Config struct. |
+ // Reads a config event to a (non-NULL) StreamConfig struct. |
// Only the fields that are stored in the protobuf will be written. |